<p style="text-align: right"><img src=https://raw.githubusercontent.com/migros/fotoobo/main/docs/source/fotoobo.png width="200px"></p>

# fotoobo | Fortinet Toolbox
**make IT easy**

[![GitHub release (latest by date)](https://img.shields.io/github/v/release/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/releases)
[![GitHub License](https://img.shields.io/github/license/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/blob/main/LICENSE)
![PyPi Python versions](https://img.shields.io/pypi/pyversions/fotoobo?style=plastic) \
[![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/migros/fotoobo/tests.yaml?label=tests&style=plastic)](https://github.com/migros/fotoobo/actions)
[![GitHub open issues](https://img.shields.io/github/issues-raw/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/issues?q=is%3Aissue+is%3Aopen)
[![GitHub closed issues](https://img.shields.io/github/issues-closed-raw/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/issues?q=is%3Aissue+is%3Aclosed) \
[![GitHub Repo stars](https://img.shields.io/github/stars/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/stargazers)
[![GitHub watchers](https://img.shields.io/github/watchers/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/watchers)
[![GitHub forks](https://img.shields.io/github/forks/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/forks)
[![GitHub contributors](https://img.shields.io/github/contributors/migros/fotoobo?style=plastic)](https://github.com/migros/fotoobo/graphs/contributors)

This is fotoobo, the mighty **Fo**rtinet **too**l**bo**x for managing your Fortinet environment. It
is meant to be extendable to your needs.

For detailed documentation see [fotoobo.readthedocs.io](https://fotoobo.readthedocs.io/)


# Contribution

To [contribute](CONTRIBUTING.md) to this project please start by reading and accepting our
[Collective Code Construction Contract](https://fotoobo.readthedocs.io/en/latest/developer/c4.html).


# License

fotoobo is licensed under the [LGPL v3](https://www.gnu.org/licenses/lgpl-3.0.html.en).

Since it is a python application which does not compile to a binary before distribution, we want to
clarify the following:

fotoobo may be used as an imported module under the same terms that the LGPL states for dynamically
linked (binary) libraries. So you may use fotoobo (unmodified) with code under another license (free
or commercial).

All changes to the fotoobo code itself are subject to the LGPL v3.
